@@ -6,9 +6,12 @@ if [ "$IS_CONTAINER" != "" ]; then
   golint -set_exit_status "${@}"
 else
   docker run --rm \
+    --env GO111MODULE="$GO111MODULE" \
+    --env GOFLAGS="$GOFLAGS" \
+    --env GOPROXY="$GOPROXY" \
     --env IS_CONTAINER=TRUE \
     --volume "${PWD}:/go/src/sigs.k8s.io/${REPO_NAME}:z" \
     --workdir "/go/src/sigs.k8s.io/${REPO_NAME}" \
-    openshift/origin-release:golang-1.10 \
+    openshift/origin-release:golang-1.12 \
     ./hack/go-lint.sh "${@}"
 fi
